logger

package module
v0.0.0-...-68367f0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: AGPL-3.0 Imports: 1 Imported by: 0

README

Go Logging Library

Copyright © 2025 Witine Limited and contributors.

This program is dual-licensed. You can redistribute it and/or modify it under the terms of the GNU Affero General Public License, version 3. Witine Limited also offers licensing under a commercial license.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewConsoleEncoder

func NewConsoleEncoder() zapcore.Encoder

func NewConsoleEncoderConfig

func NewConsoleEncoderConfig() zapcore.EncoderConfig

Types

This section is empty.

Source Files

  • logger.go

Directories

Path Synopsis

Jump to